@@ -86,14 +86,21 @@ def compress_zip(src_path: str, compress_abs_path: str) -> None:
     :param src_path: 待压缩文件或目录路径
     :param compress_abs_path: 压缩包输出绝对路径
     """
+    if not os.path.exists(src_path):
+        raise FileNotFoundError(src_path)
+
     with zipfile.ZipFile(compress_abs_path, "w", zipfile.ZIP_DEFLATED) as compress_file:
-        for abs_dir_path, dir_list, file_list in os.walk(src_path):
-            relative_path = abs_dir_path.replace(src_path, "")
-            relative_path = (relative_path and relative_path + os.sep) or ""
-            for filename in file_list:
-                compress_file.write(
-                    os.path.join(abs_dir_path, filename), relative_path + filename
-                )
+        if os.path.isdir(src_path):
+            for abs_dir_path, dir_list, file_list in os.walk(src_path):
+                relative_path = abs_dir_path.replace(src_path, "")
+                relative_path = (relative_path and relative_path + os.sep) or ""
+                for filename in file_list:
+                    compress_file.write(
+                        os.path.join(abs_dir_path, filename), relative_path + filename
+                    )
+        else:
+            filename = os.path.basename(src_path)
+            compress_file.write(src_path, filename)
 
 
 def extract_zip(src_zip: Union[str, Path], dst_dir: Union[str, Path]) -> None:
@@ -125,18 +132,23 @@ def extract_zip(src_zip: Union[str, Path], dst_dir: Union[str, Path]) -> None:
         raise ValueError(f"{src_zip}不是一个有效的zip文件")
 
 
-def compress_tgz(source_files, compress_name):
+def compress_tgz(source_files: str, compress_name: str):
     """将源文件打包成tar.gz格式
     :param source_files：str, 源文件路径，传入相对路径时，压缩包中也为相当路径，为绝对路径时，压缩包中同样为绝对路径
     :param compress_name: str, 生成的压缩包路径
     """
-    tar = tarfile.open(compress_name, "w:gz")
+    # 判断文件是否存在，不存在时抛错
+    if not os.path.exists(source_files):
+        raise FileNotFoundError(source_files)
 
-    for root, _dir, files in os.walk(source_files):
-        for file in files:
-            fullpath = os.path.join(root, file)
-            tar.add(fullpath)
-    tar.close()
+    with tarfile.open(compress_name, "w:gz") as tar:
+        if os.path.isdir(source_files):
+            for root, _dir, files in os.walk(source_files):
+                for file in files:
+                    fullpath = os.path.join(root, file)
+                    tar.add(fullpath)
+        else:
+            tar.add(source_files)
 
 
 def uncompress_tgz(compress_file, target_path="."):
