@@ -330,9 +330,14 @@ def get_repo_info(repo_path: Union[str, Path], remote="origin"):
 
 
 def create_branch_by_tag(
-    repo_path: Union[str, Path], tag_name: str, branch_name: str
+    repo_path: Union[str, Path], tag_name: str, branch_name: str, push: bool = True
 ) -> bool:
-    """根据tag创建新分支"""
+    """根据tag/branch/commit创建新分支
+    :param repo_path: git库本地绝对路径
+    :param tag_name: 基于此对象创建新分支，可以是tag或branch或commit
+    :param branch_name: 新分支名称
+    :param push: 创建分支后是否推送到远程origin
+    """
     repo_path = Path(repo_path)
 
     file.check_path_is_exits(repo_path, path_type="dir")
@@ -358,6 +363,7 @@ def create_branch_by_tag(
         utils.execute_cmd(["git", "branch", branch_name, tag_name])
     # 切换到新分支
     utils.execute_cmd(["git", "checkout", branch_name])
-    # 将新分支推送到远程库
-    utils.execute_cmd(["git", "push", "-u", "origin", branch_name])
+    if push:
+        # 将新分支推送到远程库
+        utils.execute_cmd(["git", "push", "-u", "origin", branch_name])
     return True
